"""
Eporner API Wrapper
~~~~~~~~~~~~~~~~~~~

An API wrapper for the Eporner API.
:copyright: (c) 2021-present boobfuck
:license: MIT, see LICENSE for more details.

"""

__title__     = 'eporner'
__author__    = 'boobfuck'
__license__   = 'MIT'
__copyright__ = 'Copyright 2021-present boobfuck'
__version__   = '1.0.1'

from .http import *
from .enums import *
from .errors import *
from .client import *
